@@ -21,7 +21,6 @@
 #include "config-kcm.h"
 
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <KAboutData>
 #include <QDebug>
 #include <QStandardPaths>
@@ -42,19 +41,14 @@
 #include "statisticsprovider.h"
 
 
-K_PLUGIN_FACTORY_WITH_JSON(KCMLookandFeelFactory, "kcm_energyinfo.json", registerPlugin<KCMEnergyInfo>();)
+K_PLUGIN_FACTORY_WITH_JSON(KCMEnergyInfoFactory, "kcm_energyinfo.json", registerPlugin<KCMEnergyInfo>();)
 
 using namespace KQuickAddons;
 
 KCMEnergyInfo::KCMEnergyInfo(QObject *parent, const QVariantList &args) : ConfigModule(parent, args)
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-    qmlRegisterType<BatteryModel>();
-    qmlRegisterType<WakeUpModel>();
-#else
     qmlRegisterAnonymousType<BatteryModel>("org.kde.kinfocenter.energy.private", 1);
     qmlRegisterAnonymousType<WakeUpModel>("org.kde.kinfocenter.energy.private", 1);
-#endif
 
     qmlRegisterType<StatisticsProvider>("org.kde.kinfocenter.energy.private", 1, 0, "HistoryModel");
     qmlRegisterUncreatableType<BatteryModel>("org.kde.kinfocenter.energy.private", 1, 0, "BatteryModel",
